@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use 5.010;
 
-use parent qw( Class::Accessor::Fast Exporter );
+use parent qw( Exporter Class::Accessor::Fast);
 
 use Amazon::API::Error;
 use Amazon::API::Signature4;
@@ -67,7 +67,7 @@ __PACKAGE__->mk_accessors(
   }
 );
 
-our $VERSION = '1.3.1';
+our $VERSION = '1.3.2';
 
 our @EXPORT_OK = qw{ param_n create_urlencoded_content };
 
@@ -1458,7 +1458,7 @@ response.
 
 =head1 VERSION
 
-This documentation refers to version 1.3.1 of C<Amazon::API>.
+This documentation refers to version 1.3.2 of C<Amazon::API>.
 
 =head1 DIAGNOSTICS
 
